/// <reference types="node" />
import * as web3 from '@solana/web3.js';
import * as beetSolana from '@metaplex-foundation/beet-solana';
import * as beet from '@metaplex-foundation/beet';
import { Key } from '../types/Key';
import { TokenAmount } from '../types/TokenAmount';
export type TrifleArgs = {
    key: Key;
    tokenEscrow: web3.PublicKey;
    tokens: Map<string, TokenAmount[]>;
    escrowConstraintModel: web3.PublicKey;
    padding: number[];
};
export declare class Trifle implements TrifleArgs {
    readonly key: Key;
    readonly tokenEscrow: web3.PublicKey;
    readonly tokens: Map<string, TokenAmount[]>;
    readonly escrowConstraintModel: web3.PublicKey;
    readonly padding: number[];
    private constructor();
    static fromArgs(args: TrifleArgs): Trifle;
    static fromAccountInfo(accountInfo: web3.AccountInfo<Buffer>, offset?: number): [Trifle, number];
    static fromAccountAddress(connection: web3.Connection, address: web3.PublicKey, commitmentOrConfig?: web3.Commitment | web3.GetAccountInfoConfig): Promise<Trifle>;
    static gpaBuilder(programId?: web3.PublicKey): beetSolana.GpaBuilder<TrifleArgs>;
    static deserialize(buf: Buffer, offset?: number): [Trifle, number];
    serialize(): [Buffer, number];
    static byteSize(args: TrifleArgs): number;
    static getMinimumBalanceForRentExemption(args: TrifleArgs, connection: web3.Connection, commitment?: web3.Commitment): Promise<number>;
    pretty(): {
        key: string;
        tokenEscrow: string;
        tokens: Map<string, TokenAmount[]>;
        escrowConstraintModel: string;
        padding: number[];
    };
}
export declare const trifleBeet: beet.FixableBeetStruct<Trifle, TrifleArgs>;
